Print

Print


Author: [log in to unmask]
Date: Fri Oct 21 12:25:25 2016
New Revision: 4524

Log: (empty)

Added:
    java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterDriverOld.java
      - copied, changed from r4520, java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterDriver.java
    java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterOld.java
      - copied, changed from r4520, java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverter.java

Copied: java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterDriverOld.java (from r4520, java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterDriver.java)
 =============================================================================
--- java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverter.java	(original)
+++ java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterOld.java	Fri Oct 21 12:25:25 2016
@@ -39,7 +39,7 @@
  * @author Holly Szumila <[log in to unmask]>
  *
  */
-public class EcalRawConverter {
+public class EcalRawConverterOld {
 
     /**
      * If true, time walk correction is performed. 
@@ -155,7 +155,7 @@
      * This should be removed to a standalone ECalRawConverter solely
      * for trigger emulation.
      */
-    public EcalRawConverter() {
+    public EcalRawConverterOld() {
         // Track changes in the DAQ configuration.
         ConfigurationManager.addActionListener(new ActionListener() {
             @Override
--- java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterDriver.java	(original)
+++ java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterDriverOld.java	Fri Oct 21 12:25:25 2016
@@ -19,7 +19,7 @@
 
 /**
  * This <code>Driver</code> converts raw ECal data collections to {@link org.lcsim.event.CalorimeterHit} collections 
  * with energy and time information.  The {@link EcalRawConverter} does most of the low-level work.
  * <p>
  * The following input collections are used:
  * <ul>
@@ -30,12 +30,12 @@
  * <p>
  * The results are by default written to the <b>EcalCalHits</b> output collection.
  */
-public class EcalRawConverterDriver extends Driver {
+public class EcalRawConverterDriverOld extends Driver {
 
     // To import database conditions
     private EcalConditions ecalConditions = null;
 
-    private EcalRawConverter converter = null;
+    private EcalRawConverterOld converter = null;
     /**
      * Input collection name (unless runBackwards=true, then it's output).
      * Can be a {@link org.lcsim.event.RawTrackerHit} or {@link org.lcsim.event.RawCalorimeterHit}
@@ -113,8 +113,8 @@
      */
     private boolean emulateFirmware = true;
     
-    public EcalRawConverterDriver() {
-        converter = new EcalRawConverter();
+    public EcalRawConverterDriverOld() {
+        converter = new EcalRawConverterOld();
     }
 
     /**
@@ -19,7 +19,7 @@
 /**
  * This <code>Driver</code> converts raw ECal data collections to {@link org.lcsim.event.CalorimeterHit} collections 
- * with energy and time information.  The {@link EcalRawConverter} does most of the low-level work.
+ * with energy and time information.  The {@link EcalRawConverterOld} does most of the low-level work.
  * <p>
  * The following input collections are used:

Copied: java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverterOld.java (from r4520, java/branches/converter-div/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverter.java)
 =============================================================================